==> estateplat-common-1.2.3-20180706.091355-141-sources.jar: cn/gtmap/estateplat/model/exchange/court/GxPeKzqqXm.java <==
package cn.gtmap.estateplat.model.exchange.court;

import javax.persistence.Id;
import javax.persistence.Table;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;

/*
 * @author <a href="mailto:yinyao@gtmap.cn">yinyao</a>
 * @version 1.0, 2018/6/27
 * @description
 */
@XmlAccessorType(XmlAccessType.PROPERTY)
@XmlRootElement(name = "BDCQL")
@Table(name = "gx_pe_kzqq_xm")
public class GxPeKzqqXm {
    @Id
    private String xmid;//主键
    private String cxqqdh;//控制请求单号
    private String kzcs;//控制措施
    private String bdcqllx;//不动产权利类型
    private String bdcdyh;//不动产单元号
    private String zl;//坐落
    private String bdcqzh;//不动产权证号
    private String ckwh;//裁定书文号
    private String ksrq;//申请控制开始时间，格式：2015/08/14
    private String jsrq;//申请控制结束时间，格式：2018/08/14
    private String ydjah;//原冻结案号
    private String ydjdh;//原冻结请求单号


    public String getXmid() {
        return xmid;
    }

    public void setXmid(String xmid) {
        this.xmid = xmid;
    }


    public String getCxqqdh() {
        return cxqqdh;
    }

    public void setCxqqdh(String cxqqdh) {
        this.cxqqdh = cxqqdh;
    }

    @XmlElement(name = "KZCS")
    public String getKzcs() {
        return kzcs;
    }

    public void setKzcs(String kzcs) {
        this.kzcs = kzcs;
    }

    @XmlElement(name = "BDCQLLX")
    public String getBdcqllx() {
        return bdcqllx;
    }

    public void setBdcqllx(String bdcqllx) {
        this.bdcqllx = bdcqllx;
    }

    @XmlElement(name = "BDCDYH")
    public String getBdcdyh() {
        return bdcdyh;
    }

    public void setBdcdyh(String bdcdyh) {
        this.bdcdyh = bdcdyh;
    }

    @XmlElement(name = "ZL")
    public String getZl() {
        return zl;
    }

    public void setZl(String zl) {
        this.zl = zl;
    }

    @XmlElement(name = "BDCQZH")
    public String getBdcqzh() {
        return bdcqzh;
    }

    public void setBdcqzh(String bdcqzh) {
        this.bdcqzh = bdcqzh;
    }

    @XmlElement(name = "CKWH")
    public String getCkwh() {
        return ckwh;
    }

    public void setCkwh(String ckwh) {
        this.ckwh = ckwh;
    }

    @XmlElement(name = "KSRQ")
    public String getKsrq() {
        return ksrq;
    }

    public void setKsrq(String ksrq) {
        this.ksrq = ksrq;
    }

    @XmlElement(name = "JSRQ")
    public String getJsrq() {
        return jsrq;
    }

    public void setJsrq(String jsrq) {
        this.jsrq = jsrq;
    }

    @XmlElement(name = "YDJAH")
    public String getYdjah() {
        return ydjah;
    }

    public void setYdjah(String ydjah) {
        this.ydjah = ydjah;
    }

    @XmlElement(name = "YDJDH")
    public String getYdjdh() {
        return ydjdh;
    }

    public void setYdjdh(String ydjdh) {
        this.ydjdh = ydjdh;
    }


}

==> estateplat-common-1.2.3-20180709.024845-143-sources.jar: cn/gtmap/estateplat/model/exchange/court/GxPeKzqqXm.java <==
package cn.gtmap.estateplat.model.exchange.court;

import javax.persistence.Id;
import javax.persistence.Table;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import java.io.Serializable;

/*
 * @author <a href="mailto:yinyao@gtmap.cn">yinyao</a>
 * @version 1.0, 2018/6/27
 * @description
 */
@XmlAccessorType(XmlAccessType.PROPERTY)
@XmlRootElement(name = "BDCQL")
@Table(name = "gx_pe_kzqq_xm")
public class GxPeKzqqXm implements Serializable {
    @Id
    private String xmid;//主键
    private String cxqqdh;//控制请求单号
    private String kzcs;//控制措施
    private String bdcqllx;//不动产权利类型
    private String bdcdyh;//不动产单元号
    private String zl;//坐落
    private String bdcqzh;//不动产权证号
    private String ckwh;//裁定书文号
    private String ksrq;//申请控制开始时间，格式：2015/08/14
    private String jsrq;//申请控制结束时间，格式：2018/08/14
    private String ydjah;//原冻结案号
    private String ydjdh;//原冻结请求单号


    public String getXmid() {
        return xmid;
    }

    public void setXmid(String xmid) {
        this.xmid = xmid;
    }


    public String getCxqqdh() {
        return cxqqdh;
    }

    public void setCxqqdh(String cxqqdh) {
        this.cxqqdh = cxqqdh;
    }

    @XmlElement(name = "KZCS")
    public String getKzcs() {
        return kzcs;
    }

    public void setKzcs(String kzcs) {
        this.kzcs = kzcs;
    }

    @XmlElement(name = "BDCQLLX")
    public String getBdcqllx() {
        return bdcqllx;
    }

    public void setBdcqllx(String bdcqllx) {
        this.bdcqllx = bdcqllx;
    }

    @XmlElement(name = "BDCDYH")
    public String getBdcdyh() {
        return bdcdyh;
    }

    public void setBdcdyh(String bdcdyh) {
        this.bdcdyh = bdcdyh;
    }

    @XmlElement(name = "ZL")
    public String getZl() {
        return zl;
    }

    public void setZl(String zl) {
        this.zl = zl;
    }

    @XmlElement(name = "BDCQZH")
    public String getBdcqzh() {
        return bdcqzh;
    }

    public void setBdcqzh(String bdcqzh) {
        this.bdcqzh = bdcqzh;
    }

    @XmlElement(name = "CKWH")
    public String getCkwh() {
        return ckwh;
    }

    public void setCkwh(String ckwh) {
        this.ckwh = ckwh;
    }

    @XmlElement(name = "KSRQ")
    public String getKsrq() {
        return ksrq;
    }

    public void setKsrq(String ksrq) {
        this.ksrq = ksrq;
    }

    @XmlElement(name = "JSRQ")
    public String getJsrq() {
        return jsrq;
    }

    public void setJsrq(String jsrq) {
        this.jsrq = jsrq;
    }

    @XmlElement(name = "YDJAH")
    public String getYdjah() {
        return ydjah;
    }

    public void setYdjah(String ydjah) {
        this.ydjah = ydjah;
    }

    @XmlElement(name = "YDJDH")
    public String getYdjdh() {
        return ydjdh;
    }

    public void setYdjdh(String ydjdh) {
        this.ydjdh = ydjdh;
    }


}
